@@ -172,3 +172,49 @@ class ParameterConfiguration(object):
         if type(parameter_value) != type(default):
             return default
         return parameter_value
+
+
+class RemoteConfigParameter(object):
+
+    def __init__(self, id, key, type, identifier_type, target_rules, default_value):
+        self.id = id
+        self.key = key
+        self.type = type
+        self.identifier_type = identifier_type
+        self.target_rules = target_rules
+        self.default_value = default_value
+
+    def __str__(self):
+        return 'RemoteConfigParameter(id={}, key={}, type={}, identifier_type={}, target_rules={}, default_value={})' \
+            .format(self.id,
+                    self.key,
+                    self.type,
+                    self.identifier_type,
+                    self.target_rules,
+                    self.default_value)
+
+
+class RemoteConfigTargetRule(object):
+
+    def __init__(self, key, name, target, bucket_id, value):
+        self.key = key
+        self.name = name
+        self.target = target
+        self.bucket_id = bucket_id
+        self.value = value
+
+    def __str__(self):
+        return 'RemoteConfigTargetRule(key={}, name={}, target={}, bucket_id={}, value={})'.format(self.key,
+                                                                                                   self.name,
+                                                                                                   self.target,
+                                                                                                   self.bucket_id,
+                                                                                                   self.value)
+
+
+class RemoteConfigParameterValue(object):
+    def __init__(self, id, raw_value):
+        self.id = id
+        self.raw_value = raw_value
+
+    def __str__(self):
+        return 'RemoteConfigParameterValue(id={}, raw_value={})'.format(self.id, self.raw_value)
