@@ -16,19 +16,48 @@ class ValueMatcher(object):
 
 class StringValueMatcher(ValueMatcher):
     def matches(self, operator_matcher, user_value, match_value):
-        if isinstance(user_value, string_types) and isinstance(match_value, string_types):
-            return operator_matcher.string_matches(user_value, match_value)
+        str_user_value = self.__string_or_none(user_value)
+        str_match_value = self.__string_or_none(match_value)
+        if str_user_value is not None and str_match_value is not None:
+            return operator_matcher.string_matches(str_user_value, str_match_value)
         else:
             return False
 
+    @staticmethod
+    def __string_or_none(value):
+        if isinstance(value, string_types):
+            return value
+        elif validator.is_finite_number(value):
+            return str(value)
+        else:
+            return None
+
 
 class NumberValueMatcher(ValueMatcher):
     def matches(self, operator_matcher, user_value, match_value):
-        if validator.is_finite_number(user_value) and validator.is_finite_number(match_value):
-            return operator_matcher.number_matches(user_value, match_value)
+        number_user_value = self.__number_or_none(user_value)
+        number_match_value = self.__number_or_none(match_value)
+        if number_user_value is not None and number_match_value is not None:
+            return operator_matcher.number_matches(number_user_value, number_match_value)
         else:
             return False
 
+    @staticmethod
+    def __number_or_none(value):
+        if validator.is_finite_number(value):
+            return value
+        elif isinstance(value, string_types):
+            try:
+                number = float(value)
+                if validator.is_finite_number(number):
+                    return number
+                else:
+                    return None
+            except ValueError:
+                return None
+        else:
+            return None
+
 
 class BoolValueMatcher(ValueMatcher):
     def matches(self, operator_matcher, user_value, match_value):
