@@ -42,7 +42,10 @@ class ValueOperatorMatcherFactory(object):
         self._value_matchers = {
             'STRING': StringValueMatcher(),
             'NUMBER': NumberValueMatcher(),
-            'BOOLEAN': BoolValueMatcher()
+            'BOOLEAN': BoolValueMatcher(),
+            'VERSION': VersionValueMatcher(),
+            'NULL': NoneValueMatcher(),
+            'UNKNOWN': NoneValueMatcher()
         }
         self._operator_matchers = {
             'IN': InMatcher(),
